#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-date
version: 0.0.6.1
id: http-date-0.0.6.1-ba351a4841239284d88745a26c501ccf
key: httpd_6QgAUBot1xEEOBktXWUpEg
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: HTTP Date parser/formatter
description:
    Fast parser and formatter for HTTP Date
category: Network, Web
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.HTTP.Date
hidden-modules: Network.HTTP.Date.Converter
                Network.HTTP.Date.Formatter Network.HTTP.Date.Types
                Network.HTTP.Date.Parser
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/http-date-0.0.6.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/http-date-0.0.6.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/http-date-0.0.6.1
hs-libraries: HShttp-date-0.0.6.1-6QgAUBot1xEEOBktXWUpEg
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
haddock-interfaces: /usr/share/doc/haskell-http-date/html/http-date.haddock
haddock-html: /usr/share/doc/haskell-http-date/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
